@@ -6,7 +6,7 @@ from argparse import Namespace
 from typing import Mapping, Any
 from jsonpath_ng import parse
 
-from metadata.utils.format import gen_tree_files, dict2json, dict2yaml
+from metadata.utils.format import gen_tree_files, dict2json, dict2yaml, sizeof_fmt, format_table
 from metadata.context import MetadataContext
 from metadata.entity.model import Model
 from metadata.cli.builtin.entity import IEntity
@@ -54,12 +54,12 @@ class IModel(IEntity):
         if not exists(dest):
             os.makedirs(dest)
         client = context.client
-        client.download_model(urn, dest, args.sub_paths)
+        client.download_model(urn, dest, args.sub_paths, show_progress_bar=True)
 
     @classmethod
     def do_upload(cls, context: MetadataContext, args: Namespace):
         client = context.client
-        uri = client.upload_artifact(args.storage_prefix, args.path_prefix, args.file)
+        uri = client.upload_artifact(args.storage_prefix, args.path_prefix, args.file, show_progress_bar=True)
         storage_cilent = context.storage_client
         urn = Model.gen_urn(context, storage_cilent.get_name(), args.name)
         entity = Model(
@@ -74,15 +74,26 @@ class IModel(IEntity):
     def do_upload_partial(cls, context: MetadataContext, args: Namespace):
         client = context.client
         model = client.get_model(args.urn)
-        client.upload_artifact(model.uri, args.path_prefix, args.file)
+        client.upload_artifact(model.uri, args.path_prefix, args.file, show_progress_bar=True)
 
     @classmethod
     def do_describe(cls, context: MetadataContext, args: Namespace, urn: str):
         cilent = context.client
         model = cilent.get_model(urn)
         paths = context.storage_client.list(model.uri, recursive=True)
+
+        if args.output == 'table' or not args.output:
+            metas = [context.storage_client.get_meta(path) for path in paths]
+            headers = ['path', 'entityTag', 'lastModified', 'contentLength']
+            properties = [
+                (meta['path'], meta['entityTag'], sizeof_fmt(meta['contentLength']), meta['lastModified'])
+                for meta in metas
+            ]
+            print(format_table(headers, properties, show_headers=not args.no_headers))
+            return
+
         paths = [i[len(model.uri) + 1:] for i in paths]
-        files = gen_tree_files(paths)
+        files = gen_tree_files(paths) if paths else []
         if args.output and args.output == 'yaml':
             print(dict2yaml(files))
         else:
