@@ -30,8 +30,9 @@ def do_login(args):
 
     bohrium_user = args.bohrium_user or config.get('ACCOUNT_EMAIL')
     bohrium_password = args.bohrium_password or config.get('ACCOUNT_PASSWORD')
-    bohrium_url = args.bohrium_url or config.get('PROGRAM_CURRENT_PROGRAM_ID')
-    tiefblue_url = args.tiefblue_url
+    bohrium_url = args.bohrium_url or 'https://bohrium.dp.tech'
+    tiefblue_url = args.tiefblue_url or 'https://tiefblue.dp.tech'
+    print(locals())
 
     ensure_true(bohrium_user, 'Bohrium user required')
     ensure_true(bohrium_password, 'Bohrium user required')
