@@ -90,7 +90,7 @@ class ModelMixin:
             facts.append(('owners', [make_user_urn(self.context.user_email if owner == 'me' else owner)], False, 'CONTAIN'))
         return self._get_entities_by_facts(Model.entity_type, facts, search=search, start=start, count=count) 
     
-    def download_model(self, urn: str, dest: str, sub_paths: Optional[List[str]]):
+    def download_model(self, urn: str, dest: str, sub_paths: Optional[List[str]], show_progress_bar: str=False):
         model = self.get_model(urn)
         storage_client = self.context.storage_client
         ensure_true(storage_client, 'Storage Client required for context')
@@ -101,4 +101,4 @@ class ModelMixin:
             if sub_paths and not rfile.startswith(sub_paths):
                 continue
             target = os.path.abspath(os.path.join(dest, rfile))
-            storage_client.download(file, target)
+            storage_client.download(file, target, show_progress_bar=show_progress_bar)
