@@ -6,7 +6,7 @@ from typing import Dict, List, Optional
 
 
 @dataclass
-class WorkFlow:
+class Workflow:
 
     name: str
 
@@ -19,4 +19,6 @@ class WorkFlow:
     owners: Optional[List[str]] = field(repr=False, default_factory=list)
 
     def __post_init__(self):
-        self.id = self.id or uuid.uuid4().hex
\ No newline at end of file
+        self.id = self.id or uuid.uuid4().hex
+
+WorkFlow = Workflow
\ No newline at end of file
